==> varSelectIP_0.1-5.tar.gz: varSelectIP/R/BayesFactorProbit.R <==
BayesFactorProbit <- function(Z, covariates.retain=NULL, covariates.test, 
                              current.model, parallel=FALSE){

  #############################################################################
  marginalZ.serial <- function() {
      Sigma.j <- diag(nn) + 2 * nn/k * H
      lower <- c(rep(-Inf, n0), rep(0, n1))
      upper <- c(rep(0, n0), rep(Inf, n1))
      
      del <- rep(0, times=nn)
      corrMat <- cov2cor(Sigma.j)
  
      interval.length <- 0.4
      MLE.alpha <- qnorm(mean(Z))
      alphas <- seq(MLE.alpha - 6, MLE.alpha + 6, by=interval.length)
  
      output <- 0
      for (ii in 1:length(alphas)) {
        lower.tmp <- (lower - alphas[ii])/sqrt(diag(Sigma.j))
        upper.tmp <- (upper - alphas[ii])/sqrt(diag(Sigma.j))
        output <- output + pmvt(lower=lower.tmp, upper=upper.tmp, df=0, 
                  corr=corrMat, delta=del, abseps=1e-35, 
                  algorithm=GenzBretz())[1]
      }
    
      return(output * interval.length)
  }
  #############################################################################
  marginalZ.parallel <- function() {
    Sigma.j <- diag(nn) + 2 * nn/k * H
    lower <- c(rep(-Inf, n0), rep(0, n1))
    upper <- c(rep(0, n0), rep(Inf, n1))

    del <- rep(0, times=nn)
    corrMat <- cov2cor(Sigma.j)

    interval.length <- 0.4
    MLE.alpha <- qnorm(mean(Z))
    alphas <- as.matrix(seq(MLE.alpha - 6, MLE.alpha + 6, by=interval.length))

    computeBF <- function(alpha.tmp) {
      lower.tmp <- (lower - alpha.tmp)/sqrt(diag(Sigma.j))
      upper.tmp <- (upper - alpha.tmp)/sqrt(diag(Sigma.j))
      pmvt(lower=lower.tmp, upper=upper.tmp, df=0, corr=corrMat, delta=del,
           abseps=1e-35, algorithm=GenzBretz())[1]
    }

    mpi.bcast.Robj2slave(lower)
    mpi.bcast.Robj2slave(upper)
    mpi.bcast.Robj2slave(corrMat)
    mpi.bcast.Robj2slave(del)
    mpi.bcast.Robj2slave(Sigma.j)
    mpi.bcast.Robj2slave(alphas)
    mpi.bcast.Robj2slave(computeBF)
    output <- sum(mpi.parApply(alphas, 1, computeBF))

    return(output * interval.length)
  }
  #############################################################################

  if(is.null(covariates.retain) & (sum(current.model) == 0)) {
    return
  }

  n0 <- sum(Z == 0)
  nn <- length(Z)
  n1 <- nn - n0

  Xtmp <- cbind(rep(1, length(Z)), covariates.retain, 
                  covariates.test[ , which(current.model == 1)])
  XtX_inv <- solve(t(Xtmp) %*% Xtmp)

  H <- Xtmp %*% XtX_inv %*% t(Xtmp) # HAT matrix

  # total number of covariates (including intercept)
  k <- ncol(Xtmp)  
 
  if (parallel)
    output <- marginalZ.parallel()
  else 
    output <- marginalZ.serial()
  
  return(output)
}

==> varSelectIP_0.2-1.tar.gz: varSelectIP/R/BayesFactorProbit.R <==
BayesFactorProbit <- function(Z, covariates.retain=NULL, covariates.test, 
                              current.model){

  #############################################################################
  marginalZ.serial <- function() {
      Sigma.j <- diag(nn) + 2 * nn/k * H
      lower <- c(rep(-Inf, n0), rep(0, n1))
      upper <- c(rep(0, n0), rep(Inf, n1))
      
      del <- rep(0, times=nn)
      corrMat <- cov2cor(Sigma.j)
  
      interval.length <- 0.4
      MLE.alpha <- qnorm(mean(Z))
      alphas <- seq(MLE.alpha - 6, MLE.alpha + 6, by=interval.length)
  
      output <- 0
      for (ii in 1:length(alphas)) {
        lower.tmp <- (lower - alphas[ii])/sqrt(diag(Sigma.j))
        upper.tmp <- (upper - alphas[ii])/sqrt(diag(Sigma.j))
        output <- output + pmvt(lower=lower.tmp, upper=upper.tmp, df=0, 
                  corr=corrMat, delta=del, abseps=1e-35, 
                  algorithm=GenzBretz())[1]
      }
    
      return(output * interval.length)
  }
  #############################################################################
  #############################################################################

  if(is.null(covariates.retain) & (sum(current.model) == 0)) {
    return
  }

  n0 <- sum(Z == 0)
  nn <- length(Z)
  n1 <- nn - n0

  Xtmp <- cbind(rep(1, length(Z)), covariates.retain, 
                  covariates.test[ , which(current.model == 1)])
  XtX_inv <- solve(t(Xtmp) %*% Xtmp)

  H <- Xtmp %*% XtX_inv %*% t(Xtmp) # HAT matrix

  # total number of covariates (including intercept)
  k <- ncol(Xtmp)  
 
    output <- marginalZ.serial()
  
  return(output)
}
